import { defineConfig } from "vite";
import react from "@vitejs/plugin-react";
import dts from "vite-plugin-dts";
import cssInjectedByJsPlugin from "vite-plugin-css-injected-by-js";

// https://vitejs.dev/config/
export default defineConfig({
  plugins: [
    react(),
    cssInjectedByJsPlugin(),
    dts({
      insertTypesEntry: true,
      rollupTypes: false,
      copyDtsFiles: true,
      // Additional configuration options as needed
    }),
  ],
  build: {
    lib: {
      entry: "src/index.ts", // Your library entry point
      name: "RoRo-Fume", // Global variable when using UMD build
      fileName: (format: string) => `roro-fume.${format}.js`, // Output file name
    },
    rollupOptions: {
      // Externalize peer dependencies
      external: ["react", "react-dom"],
      output: {
        // Provide global variables to use in the UMD build for externalized deps
        globals: {
          react: "React",
          "react-dom": "ReactDOM",
        },
      },
    },
  },
});
